@@ -1405,7 +1405,7 @@ def _scan(command, data_or_file, ext_vars={}, base_dir=DEFAULT_BASE_DIR, socket_
 
             # if we've swung back around wait for a few seconds and try again
             if scanner_index == starting_index:
-                log.error("no scanners available")
+                log.warning("no scanners available")
                 raise
 
             continue
